#
# spec file for package sdlpop
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sdlpop
Version:        1.23
Release:        5.1
Summary:        An open-source port of Prince of Persia
License:        GPL-3.0-only
Group:          Amusements/Games/Other
URL:            https://www.popot.org/get_the_games.php?game=SDLPoP
Source0:        https://github.com/NagyD/SDLPoP/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        sdlpop.wrapper
Patch0:         sdlpop-fix-sdl2-includes.patch
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  make
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(sdl2)
ExcludeArch:    s390x

%description
SDLPoP is an open-source port of Prince of Persia 1,
that runs natively under Linux. It is based on the DOS
version of the game, and uses SDL.

Run the prince executable in a path were the original
game data files are located.

%prep
%autosetup -p1 -n SDLPoP-%{version}
sed -i 's/\r$//' doc/*.txt

%build
cd src
%make_build

%install
install -d %{buildroot}/%{_bindir}
install -Dm0755 prince %{buildroot}/%{_bindir}
install -Dm0644 data/icon.png %{buildroot}/%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
install -d %{buildroot}/%{_datadir}/%{name}
install SDLPoP.ini %{buildroot}/%{_datadir}/%{name}
mv data/ %{buildroot}/%{_datadir}/%{name}
%suse_update_desktop_file -c %{name} %{name} "Platformer" %{name} %{name} Game ActionGame
%fdupes %{buildroot}/%{_datadir}

# Install Wrapper
install -Dm0755 %{SOURCE1} %{buildroot}%{_bindir}/%{name}
ln -s %{_bindir}/prince %{buildroot}%{_datadir}/%{name}

%files
%doc README.md doc/tiles.md doc/mod.ini doc/ChangeLog.txt
%license COPYING
%attr(0755,root,root) %{_bindir}/sdlpop
%{_bindir}/prince
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/32x32/apps/sdlpop.png
%{_datadir}/applications/sdlpop.desktop

%changelog
* Wed Jun 26 2024 Andrea Manzini <andrea.manzini@suse.com>
- moved binary to /usr/bin and asset data to /usr/share/sdlpop
  (https://bugzilla.suse.com/show_bug.cgi?id=1226830)
* Sun Apr  7 2024 Christian Boltz <suse-beta@cboltz.de>
- sdlpop doesn's support big endian CPUs, stop building for s390x
* Wed Mar 20 2024 Andrea Manzini <andrea.manzini@suse.com>
- Fixed segfault https://bugzilla.opensuse.org/show_bug.cgi?id=1221544
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Jan 23 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 1.23
  Fixed:
  * Don't hardcode level 13 for the loose floor events.
  * If a sprite's xpos is negative and divisible by 8, it appeared shifted 8 pixels to the left.
  * If the place of a special event was changed, show it at its new place on level maps.
  * Fixed black rectangle appearing when the shadow falls into the wall.
  * Make the +/- keys work on the main keyboard, on any keyboard layout.
  * Fixed crash when trying to load a non-existent mod from command line.
  * Allow running without haptic support in SDL
  * Save the current options (not the defaults) into the replay!
  * Fix guards disappearing when the player (re-)enters the currently shown room.
  * Fix crashing with the guard graphics of Christmas of Persia. (with SDL_image 2.6.2)
  * Select "SETTINGS" in the pause menu, if coming back from the settings menu.
  * Fixed some compiler and cppcheck warnings.
  Done:
  * Mention the tricks page in the INI, since tricks are mentioned there.
  * Show guards' HP and skills on the maps.
  * Added super high jump option.
  * Added options to use the original music and/or graphics for custom levelsets.
  * Added comments about unused fields in the level data.
  * Added gamecontroller hotplug support. SDLPoP now detects controllers plugged in while the game is already running.
  * Briefly show a dark screen when changing rooms, like in the original game.
  * Moved the license and readme to a more common location.
  * Fix jumping over guard
  * Level maps: If the skeleton's respawn position is customized, mark it at the new place.
  * Fix detection of allow_triggering_any_tile in Micro Palace.
  * Make hardware acceleration a runtime option
  * Added an ability to grab tiles while jumping forward.
  * Fixed the skeleton fall check.
  * Documented SDLPoP-specific tiles. See doc/tiles.md.
  * During text input, display the screen keyboard if supported.
  * Made the source more readable.
  * Added support for teleports. See USE_TELEPORTS in config.h.
  * Added a rounded border around the icon.
  * Show the hotkeys for quicksave/load in the menu (instead of the splash screen). Mention the menu on the splash screen.
  * Keep disappearing guard logic for super high jump consistent with the stand-alone option.
  * Updated doc/mod.ini based on SDLPoP.ini.
* Sat Jul 10 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.22
  Fixed:
  * The prince can now grab a ledge at the bottom right corner of
    a room with no room below.
  * Don't allow killing a skeleton in cheat mode.
  * Ctrl+S didn't mute music (except death music).
  * A falling tile on the left side of a pillar could cause the
    blue stripe to be drawn over the pillar.
  * The top of moving gates became glitched on levels using
    non-default palettes.
  * The right edge of pressed drop buttons was black if a big
    pillar was next to them.
  * Guards appeared in the current room when they fell into spikes
    in an adjacent room. (Example: original level 11, room 22.)
  * Show an error message if a data file is missing.
  * Colored torches were not restored on quickload if you
    (quit and) restarted the game after quicksave.
  * Fixed compiling with some features #undefined. (USE_TEXT,
    USE_LIGHTING, USE_MENU)
  * Fixed the detection of Ctrl+L during the demo level.
  * Create the screenshots directory in SDLPoP's directory, even
    if the current directory is something else.
    This is to match how the replay folder works.
  * After quickload, show the room where the prince is, even if
    the player moved the view away from it (with the H,J,U,N keys).
  * After quickload, don't draw guard HP if a previously viewed
    room (with the H,J,U,N keys) had a guard but the current room
    doesn't have one.
  * Prevent the modifier remapping from accessing out-of-range
    rooms.
  * Don't show the mirror image if the prince is not in the
    currently shown room.
  * Fixed the length of feather fall in fast-forward mode.
  * Prevent torches from being randomly colored when an older
    replay is loaded.
  * If the prince is fighting a guard, and the player does a
    quickload to a state where the prince is near the mouse, the
    prince would draw the sword.
  * Fixed graphical glitches with an opening gate:
    1. with a loose floor above and a wall above-right.
    2. with the top half of a big pillar above-right.
    See FIX_ABOVE_GATE in config.h .
  * Validate mode crashed with the error "init_scaling:
    SDL_CreateTexture: Invalid renderer".
  * Fixed crashing when a MIDI music interrupted another one.
  * Make it possible to go through a certain closed gate on
    level 11 of Demo by Suave Prince.
  * When the prince jumps up at the bottom of a big pillar split
    between two rooms, a part near the top of the screen
    disappears.
    + Example: The top row in the first room of the original
    level 5.
    + Details: See FIX_BIGPILLAR_JUMP_UP in config.h .
  * Fixed spiked/chomped/bumped guards teleporting into the wrong
    room. (if fixes are enabled)
  * Quicksave during feather fall mode. (if fixes are enabled)
  * Prevent the prince from entering a glitched room when he
    falls into a wall or he is revived near a wall.
  * Optimized OPL mixing (MIDI music).
  * Fixed the prince sliding through closed gates when you are
    using the caped prince graphics.
  * If the prince dies on level 14, don't return to the intro
    after the level was restarted.
  Done:
  * Added command-line parameter "mute": Start the game with
    sound off.
  * Hide references to various features if the game was compiled
    without them.
  * A scrollbar appears in the pause menu if scrolling is
    possible.  It's not clickable yet, it just shows where you are
    in the list.
  * Added command-line parameter "playdemo": Make the demo level
    playable.
  * Speed up music, sounds, and transitions during fast forwarding.
  * Added a new cheat key: Ctrl+B: Go back to the room where the
    prince is. (Undo H,J,U,N.)
  * Added options for changing speeds. They are detected from
    PRINCE.EXE. (Used in Hurry up Prince, for example.)
  * In the settings menu, allow using Page Up, Page Down, Home, End.
  * Rewrote all mentions of key combinations to the "Ctrl+A" style.
  * Marked which features of SDLPoP are not in the original game.
  * Allow Backspace and Ctrl+C during replay.
  * During playback, display the number of ticks since start, if
    the timer is shown (debug cheats: T).
  * Added a debug cheat to quickload but keep the currently loaded
    level. (Shift+F9)
  * Added a compilation-time flag to disable all fixes for vanilla
    execution.
  * Waste an RNG cycle in loose_shake() to match DOS PoP.
  * In new replays, use deprecation_number = 2. On playback, waste
    the RNG cycle only if deprecation_number >= 2.
    Older replays have deprecation_number <= 1, and we don't waste
    the RNG cycle when playing them back.
  * When backing offscreen (to the left) from the first guard on
    level 7 (among others), simulate the glitch from DOS PoP,
    which causes the prince to fall through the floor.
  * Added a more visible error message when a mod referenced by a
    replay file cannot be found in the mods folder.
  * Allow guard skill customizations in SDLPoP.ini.
  * Made FIX_DOORTOP_DISABLING_GUARD configurable.
- Add patch:
  * sdlpop-fix-sdl2-includes.patch
* Sat Aug 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.21
  Fixed:
  * Skeletons not on level 3 did not behave like skeletons.
  * Don't crash if the intro music is interrupted by Tab in PC
    Speaker mode.
  * Don't switch to PC Speaker mode if there is a mod name in the
    replay file.
  * Don't draw the right edge of loose floors on the left side of a
    potion or sword.
  * A guard standing on a door top (with floor) should not become
    inactive.
  * Left jump (top-left) didn't work on some gamepads.
  * Replaying from the command line did not work if there were no
    replay files in the replay folder.
  Done:
  * Detect guard skill customizations in PRINCE.EXE. (Used in
    Illusions of Persia, for example.)
  * Added support for gamecontrollerdb.txt file.
  * Detect changes of the shadow's starting positions and
    automatic moves in PRINCE.EXE.
  * Added "Restart Game" to the pause menu, so now it's possible
    to restart the game using a controller.
  * Added fast forward.
  Added:
  * You can now use quicksave and quickload while recording a
    replay.
- Drop patch:
  * 184.patch (fixed by upstream)
* Wed Oct 23 2019 Martin Hauke <mardnh@gmx.de>
- Do not longer use rpm macros that are not longer needed on
  recent distros:
  * %%desktop_database_post
  * %%icon_theme_cache_post
* Tue Oct 15 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.20
  * Fixed crash on Linux when the prince fell out of the level
    while a guard was active.
  * FIXED: With start_in_blind_mode enabled, moving objects were
    not displayed until blind mode was toggled off+on.
  * Fix upside-down screen when using PRINCE.EXE from v1.3 or v1.4.
  * Added customization option for loose floor delay. (Used in
    Neon Persia.)
  * Fix detection of "allow triggering any tile" hack.
  * Enable use_custom_options by default in the INI.
  * Fix priorities of sword and spike sounds. (As in PoP 1.3.)
    The "spiked" sound didn't interrupt the normal spikes sound when
    the prince ran into spikes. With PoP 1.3 sounds, the "guard hurt"
    sound didn't play when you hit a guard directly after parrying.
- Add patch:
  * 184.patch (CMake: Don't link SDL2main on Linux)
    https://github.com/NagyD/SDLPoP/pull/184/files
* Sun Mar 31 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.19
  * Fix looping "sword moving" sound if the player leaves a room
    exactly when a guard attacks.
  * Support 8-bpp images in DAT files. For example the Pyramid mod
    contains some of these.
  * Improved map-making on levels with broken room links: If a room
    is mapped to an already used place, then put it to the bottom of
    the map.
  * Better support for high-DPI (Retina) displays.
  * Disable integer scaling menu item if SDL version is too old.
  * Made the exit door fix configurable.
  * Torches appearing in the leftmost column are now animated. (They
    are actually in the rightmost column of the left-side room.)
  New Features:
  * Load custom options from DOS PRINCE.EXE files.
  * Added a hotkey to display SDL versions. (Ctrl-C)
  * Save screenshots and maps into a separate folder and add numbers
    to the filenames.
  * Added support for PC speaker sounds. Use command-line parameter
    "stdsnd".
  * Added support for colored torch flames.
* Sun Jun 10 2018 mardnh@gmx.de
- Use CMake for building
- Package data files
- Update to version 1.18.1
* Sat Jul 15 2017 mailaender@opensuse.org
- update to version 1.17
- add .desktop file with icon
* Sat May 21 2016 mailaender@opensuse.org
- use source tarballs https://github.com/NagyD/SDLPoP/issues/62
* Sat Mar 26 2016 mailaender@opensuse.org
- initial packaging of version 1.16
